package com.huimv.production.datasource.controller;

import com.alibaba.fastjson.JSONObject;
import com.huimv.common.result.Result;
import com.huimv.common.result.ResultCode;
import com.huimv.production.datasource.service.IErpDataService;
import com.huimv.production.datasource.utils.TokenUtil;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.repository.query.Param;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * @Project :
 * @Package : com.huimv.production.datasource.controller
 * @Description : TODO
 * @Version : 1.0
 * @Author : ZhuoNing
 * @Create : 2020-12-25
 **/
@RestController
@RequestMapping(value = "/erpData",method=RequestMethod.GET)
public class ErpDataController {

    @Autowired
    private IErpDataService erpDataService;
    @Autowired
    private TokenUtil tokenUtil;
    /**
     * @Method      : getPsy
     * @Description : 获取Psy
     * @Params      : []
     * @Return      : java.lang.String
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/5/14       
     * @Time        : 20:57
     */
    @RequestMapping("/getPsy")
    public Result getPsy(@Param(value="farmID") String farmID,@Param(value="startDate") String startDate,@Param(value="endDate") String endDate,@RequestParam(value = "accessToken",required = true) String accessToken){
        // 验证token
        Result result = tokenUtil.verifyToken(accessToken);
        if(!result.isSuccess()){
            return result;
        }
        return new Result(ResultCode.SUCCESS,erpDataService.getPsy(farmID,startDate,endDate));
    }

    /**
     * @Method      : getReEstrusRate
     * @Description : 获取返情率
     * @Params      : []
     * @Return      : java.lang.String
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/5/14       
     * @Time        : 21:14
     */
    @RequestMapping("/getReEstrusRate")
    public Result getReEstrusRate(@Param(value="startDate") String startDate,@Param(value="endDate") String endDate,@RequestParam(value = "accessToken",required = true) String accessToken,@RequestParam(value = "farmName",required = true) String farmName){
        // 验证token
        Result result = tokenUtil.verifyToken(accessToken);
        if(!result.isSuccess()){
            return result;
        }
        return new Result(ResultCode.SUCCESS,erpDataService.getReEstrusRate(startDate,endDate,farmName));
    }

    /**
     * @Method      : getParturitionRate
     * @Description : 获取分娩率
     * @Params      : []
     * @Return      : java.lang.String
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/5/15       
     * @Time        : 11:02
     */
    @RequestMapping("/getParturitionRate")
    public Result getParturitionRate(@Param(value="startDate") String startDate,@Param(value="endDate") String endDate,@RequestParam(value = "accessToken",required = true) String accessToken,@RequestParam(value = "farmName",required = true) String farmName){
        // 验证token
        Result result = tokenUtil.verifyToken(accessToken);
        if(!result.isSuccess()){
            return result;
        }
        return new Result(ResultCode.SUCCESS,erpDataService.getParturitionRate(startDate,endDate,farmName));
    }

    /**
     * @Method      : getStorage
     * @Description : 获取各品种及各自存栏
     * @Params      : []
     * @Return      : java.lang.String
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/5/15       
     * @Time        : 11:16
     */
    @RequestMapping("/getStorage")
    public Result getStorage(@RequestParam(value = "accessToken",required = true) String accessToken,@RequestParam(value = "farmName",required = true) String farmName){
        // 验证token
        Result result = tokenUtil.verifyToken(accessToken);
        if(!result.isSuccess()){
            return result;
        }
        return new Result(ResultCode.SUCCESS,erpDataService.getStorage(farmName));
    }

    /**+
     * @Method      : getPigletInfo
     * @Description : 获取均产仔数
     * @Params      : []
     * @Return      : java.lang.String
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/5/15       
     * @Time        : 11:18
     */
    @RequestMapping("/getPigletInfo")
    public Result getPigletInfo(@Param(value="startDate") String startDate,@Param(value="endDate") String endDate,@RequestParam(value = "accessToken",required = true) String accessToken,@RequestParam(value = "farmName",required = true) String farmName){
        // 验证token
        Result result = tokenUtil.verifyToken(accessToken);
        if(!result.isSuccess()){
            return result;
        }
        return new Result(ResultCode.SUCCESS,erpDataService.getPigletInfo(startDate,endDate,farmName));
    }

    /**
     * @Method      : getMatingTimes
     * @Description : 配种数量
     * @Params      : []
     * @Return      : java.lang.String
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/5/15       
     * @Time        : 11:35
     */
    @RequestMapping("/getMateQuantity")
    public Result getMateQuantity(@Param(value="startDate") String startDate,@Param(value="endDate") String endDate,@RequestParam(value = "accessToken",required = true) String accessToken,@RequestParam(value = "farmName",required = true) String farmName){
        // 验证token
        Result result = tokenUtil.verifyToken(accessToken);
        if(!result.isSuccess()){
            return result;
        }
        return new Result(ResultCode.SUCCESS,erpDataService.getMateQuantity(startDate,endDate,farmName));
    }

    /**
     * @Method      : getConceptionRate
     * @Description : 受胎率
     * @Params      : []
     * @Return      : java.lang.String
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/5/15       
     * @Time        : 11:38
     */
    @RequestMapping("/getConceptionRate")
    public Result getConceptionRate(@Param(value="startDate") String startDate,@Param(value="endDate") String endDate,@RequestParam(value = "accessToken",required = true) String accessToken,@RequestParam(value = "farmName",required = true) String farmName){
        // 验证token
        Result result = tokenUtil.verifyToken(accessToken);
        if(!result.isSuccess()){
            return result;
        }
        return new Result(ResultCode.SUCCESS,erpDataService.getConceptionRate(startDate,endDate,farmName));
    }

    /**
     * @Method      : getAllStorage
     * @Description : 总存栏，母猪存栏
     * @Params      : []
     * @Return      : java.lang.String
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/5/15       
     * @Time        : 11:39
     */
    @RequestMapping("/getAllStorage")
    public Result getAllStorage(@RequestParam(value = "accessToken",required = true) String accessToken,@RequestParam(value = "farmName",required = true) String farmName){
        // 验证token
        Result result = tokenUtil.verifyToken(accessToken);
        if(!result.isSuccess()){
            return result;
        }
        return new Result(ResultCode.SUCCESS,erpDataService.getAllStorage(farmName));
    }

    /**
     * @Method      : getPigletSurvivalRate
     * @Description : 获取仔猪存活率
     * @Params      : [startDate, endDate, accessToken, farmName]
     * @Return      : com.huimv.common.result.Result
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/6/30       
     * @Time        : 13:27
     */
    @RequestMapping("/getPigletSurvivalRate")
    public Result getPigletSurvivalRate(@Param(value="startDate") String startDate,@Param(value="endDate") String endDate,@RequestParam(value = "accessToken",required = true) String accessToken,@RequestParam(value = "farmID",required = true) String farmID){
        // 验证token
        Result result = tokenUtil.verifyToken(accessToken);
        if(!result.isSuccess()){
            return result;
        }
        return new Result(ResultCode.SUCCESS,erpDataService.getPigletSurvivalRate(startDate,endDate,farmID));
    }
}
