package com.huimv.production.datasource.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.huimv.production.datasource.dao.repo.TDeliveryRepo;
import com.huimv.production.datasource.service.IErpDataService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @Project : huimv.shiwan
 * @Package : com.huimv.biosafety.uface.controller
 * @Description : TODO
 * @Version : 1.0
 * @Author : ZhuoNing
 * @Create : 2020-12-25
 **/
@Service
@Slf4j
public class ErpDataServiceImpl implements IErpDataService {
    @Value("${apiService.data.getStorage.isDemo}")
    private String isDemo;
    @Autowired
    private TDeliveryRepo tDeliveryRepo;


    /**
     * @Method : getPsy
     * @Description : Psy
     * @Params : []
     * @Return : java.lang.String
     * @Author : ZhuoNing
     * @Date : 2021/5/15
     * @Time : 11:40
     */
    @Override
    public String getPsy(String farmID, String startDate, String endDate) {
        log.info(" 开始日期（PSY） startDate:" + startDate);
        log.info(" 结束日期（PSY） endDate:" + endDate);
        List<Object[]> psyFieldList = tDeliveryRepo.getPsy(startDate, endDate, farmID);
        log.info(" 返情率查询数量:" + psyFieldList.size());
        String psy = "";
        for (Object[] goodsObj : psyFieldList) {
            psy = goodsObj[0].toString();
        }
        return psy;
    }

    /**
     * @Method : getReEstrusRate
     * @Description : 返情率
     * @Params : []
     * @Return : java.lang.String
     * @Author : ZhuoNing
     * @Date : 2021/5/15
     * @Time : 11:41
     */
    @Override
    public String getReEstrusRate(String startDate, String endDate, String farmName) {
        log.info(" 开始日期（返情率） startDate:" + startDate);
        log.info(" 结束日期（返情率） endDate:" + endDate);
        log.info(" 牧场名称（返情率） farmName:" + farmName);
        List<Object[]> reEstrusRateFieldList = tDeliveryRepo.getReEstrusRate(startDate, endDate, farmName);
        log.info(" 返情率查询数量:" + reEstrusRateFieldList.size());
        JSONArray resultJa = new JSONArray();
        for (Object[] fieldObj : reEstrusRateFieldList) {
            String farmVal = fieldObj[0].toString();
//            String varietyVal = fieldObj[1].toString();
            String reEstrusRateVal = fieldObj[1].toString();
            JSONObject dataJo = new JSONObject();
            dataJo.put("farm", farmVal);
//            dataJo.put("variety",varietyVal);
            dataJo.put("reestrus_rate", reEstrusRateVal);
            resultJa.add(dataJo);
        }

        return resultJa.toJSONString();
    }

    /**
     * @Method : getParturitionRate
     * @Description : 分娩率
     * @Params : []
     * @Return : java.lang.String
     * @Author : ZhuoNing
     * @Date : 2021/5/15
     * @Time : 11:41
     */
    @Override
    public String getParturitionRate(String startDate, String endDate, String farmName) {
        log.info(" 开始日期（分娩率） startDate:" + startDate);
        log.info(" 结束日期（分娩率） endDate:" + endDate);
        log.info(" 牧场名称（分娩率） farmName:" + farmName);
        List<Object[]> fieldList = tDeliveryRepo.getParturitionRate(startDate, endDate, farmName);
        log.info(" 分娩率查询数量:" + fieldList.size());
        JSONArray resultJa = new JSONArray();
        for (Object[] fieldObj : fieldList) {
            String farmVal = fieldObj[0].toString();
//            String varietyVal = fieldObj[1].toString();
            String reEstrusRateVal = fieldObj[1].toString();
            JSONObject dataJo = new JSONObject();
            dataJo.put("farm", farmVal);
            dataJo.put("parturition_rate", reEstrusRateVal);
            resultJa.add(dataJo);
        }

        return resultJa.toJSONString();
    }

    /**
     * @Method : getStorage
     * @Description : 各品种及各自存栏
     * @Params : []
     * @Return : java.lang.String
     * @Author : ZhuoNing
     * @Date : 2021/5/15
     * @Time : 11:42
     */
    @Override
    public String getStorage(String farmName) {
        log.info(" 牧场名称（各品种及各自存栏） farmName:" + farmName);
        List<Object[]> fieldList = tDeliveryRepo.getStorage(farmName);
        log.info(" 各种存栏查询数量:" + fieldList.size());
        JSONArray resultJa = new JSONArray();
        for (Object[] fieldObj : fieldList) {
            //
            String farm = "";
            if (fieldObj[0] == null) {
                farm = "";
            } else {
                farm = fieldObj[0].toString();
            }
            //
            String name = "";
            if (fieldObj[1] == null) {
                name = "";
            } else {
                name = fieldObj[1].toString();
            }
            //
            String quantity = "";
            if (quantity == null) {
                quantity = "";
            } else {
                quantity = fieldObj[2].toString();
            }
            JSONObject dataJo = new JSONObject();
            dataJo.put("farm", farm);
            dataJo.put("name", name);
            dataJo.put("quantity", quantity);
            resultJa.add(dataJo);
        }
        if (isDemo.equalsIgnoreCase("0")) {
            // 返回真实结果
            return resultJa.toJSONString();
        } else {
            //模拟结果
            JSONArray demoJa = new JSONArray();
            JSONObject demoJo1 = new JSONObject();
            demoJa.add(demoJo1);
            demoJo1.put("farm", "海盐曙光");
            demoJo1.put("name", "杜巴嘉");
            demoJo1.put("quantity", "2873");

            JSONObject demoJo2 = new JSONObject();
            demoJa.add(demoJo2);
            demoJo2.put("farm", "海盐曙光");
            demoJo2.put("name", "杜杜巴嘉");
            demoJo2.put("quantity", "545");

            JSONObject demoJo3 = new JSONObject();
            demoJa.add(demoJo3);
            demoJo3.put("farm", "海盐曙光");
            demoJo3.put("name", "三元");
            demoJo3.put("quantity", "555");

            JSONObject demoJo4 = new JSONObject();
            demoJa.add(demoJo4);
            demoJo4.put("farm", "海盐曙光");
            demoJo4.put("name", "嘉兴黑猪");
            demoJo4.put("quantity", "239");

            return demoJa.toJSONString();
        }
    }

    /**
     * @Method : getPigletInfo
     * @Description : 均产仔数，仔猪存活率
     * @Params : []
     * @Return : java.lang.String
     * @Author : ZhuoNing
     * @Date : 2021/5/15
     * @Time : 11:43
     */
    @Override
    public String getPigletInfo(String startDate, String endDate, String farmName) {
        log.info(" 开始日期（均产仔数，仔猪存活率） startDate:" + startDate);
        log.info(" 结束日期（均产仔数，仔猪存活率） endDate:" + endDate);
        log.info(" 牧场名称（均产仔数，仔猪存活率） farmName:" + farmName);
        List<Object[]> fieldList = tDeliveryRepo.getPigletInfo(startDate, endDate, farmName);
        log.info(" 均产仔数，仔猪存活率查询数量:" + fieldList.size());
        JSONArray resultJa = new JSONArray();
        for (Object[] fieldObj : fieldList) {
            String farm = fieldObj[0].toString();
            String birth_number = fieldObj[1].toString();
            String total = fieldObj[2].toString();
            String dead_quantity = fieldObj[3].toString();
            JSONObject dataJo = new JSONObject();
            dataJo.put("farm", farm);
            dataJo.put("birth_number", birth_number);
            dataJo.put("total", total);
            dataJo.put("dead_quantity", dead_quantity);
            resultJa.add(dataJo);
        }

        return resultJa.toJSONString();
    }

    /**
     * @Method : getMateQuantity
     * @Description : 配种数量
     * @Params : []
     * @Return : java.lang.String
     * @Author : ZhuoNing
     * @Date : 2021/5/15
     * @Time : 11:44
     */
    @Override
    public String getMateQuantity(String startDate, String endDate, String farmName) {
        log.info(" 开始日期（配种数量） startDate:" + startDate);
        log.info(" 结束日期（配种数量） endDate:" + endDate);
        log.info(" 牧场名称（配种数量） farmName:" + farmName);
        List<Object[]> fieldList = tDeliveryRepo.getMateQuantity(startDate, endDate, farmName);
        log.info(" 配种查询数量:" + fieldList.size());
        JSONArray resultJa = new JSONArray();
        for (Object[] fieldObj : fieldList) {
            String farm = fieldObj[0].toString();
//            String variety = fieldObj[1].toString();
            String mate_quantity = fieldObj[1].toString();
            JSONObject dataJo = new JSONObject();
            dataJo.put("farm", farm);
//            dataJo.put("variety",variety);
            dataJo.put("mate_quantity", mate_quantity);
            resultJa.add(dataJo);
        }

        return resultJa.toJSONString();
    }

    /**
     * @Method : getConceptionRate
     * @Description : 受胎率
     * @Params : []
     * @Return : java.lang.String
     * @Author : ZhuoNing
     * @Date : 2021/5/15
     * @Time : 11:45
     */
    @Override
    public String getConceptionRate(String startDate, String endDate, String farmName) {
        log.info(" 开始日期（受胎率） startDate:" + startDate);
        log.info(" 结束日期（受胎率） endDate:" + endDate);
        log.info(" 牧场名称（受胎率） farmName:" + farmName);
        List<Object[]> fieldList = tDeliveryRepo.getConceptionRate(startDate, endDate, farmName);
        log.info(" 受胎率查询数量:" + fieldList.size());
        JSONArray resultJa = new JSONArray();
        for (Object[] fieldObj : fieldList) {
            String farm = fieldObj[0].toString();
            String conception_rate = fieldObj[1].toString();
            JSONObject dataJo = new JSONObject();
            dataJo.put("farm", farm);
            dataJo.put("conception_rate", conception_rate);
            resultJa.add(dataJo);
        }
        return resultJa.toJSONString();
    }

    /**
     * @Method : getAllStorage
     * @Description : 总存栏，母猪存栏
     * @Params : []
     * @Return : java.lang.String
     * @Author : ZhuoNing
     * @Date : 2021/5/15
     * @Time : 11:45
     */
    @Override
    public String getAllStorage(String farmName) {
        log.info(" 牧场名称（总存栏，母猪存栏） farmName:" + farmName);
        List<Object[]> fieldList = tDeliveryRepo.getAllStorage(farmName);
        log.info(" 总存栏，母猪存栏查询数量:" + fieldList.size());
        JSONArray resultJa = new JSONArray();
        for (Object[] fieldObj : fieldList) {
            String farm = fieldObj[0].toString();
            String sow_quantity = fieldObj[1].toString();
            String total = fieldObj[2].toString();
            JSONObject dataJo = new JSONObject();
            dataJo.put("farm", farm);
            dataJo.put("sow_quantity", sow_quantity);
            dataJo.put("total", total);
            resultJa.add(dataJo);
        }
        return resultJa.toJSONString();
    }

    /**
     * @Method : getPigletSurvivalRate
     * @Description : 仔猪存活率
     * @Params : [startDate, endDate, farmName]
     * @Return : java.lang.Object
     * @Author : ZhuoNing
     * @Date : 2021/6/30
     * @Time : 13:28
     */
    @Override
    public Object getPigletSurvivalRate(String startDate, String endDate, String farmID) {
        log.info(" 开始日期（仔猪存活率） startDate:" + startDate);
        log.info(" 结束日期（仔猪存活率） endDate:" + endDate);
        log.info(" 牧场名称（仔猪存活率） farmID:" + farmID);
        List<Object[]> fieldList = tDeliveryRepo.getPigletSurvivalRate(startDate, endDate, farmID);
        log.info(" 仔猪存活率查询数量:" + fieldList.size());
        JSONArray resultJa = new JSONArray();
        for (Object[] fieldObj : fieldList) {
            String pigletSurvivalRate = fieldObj[0].toString();
            String farm = fieldObj[1].toString();
            JSONObject dataJo = new JSONObject();
            dataJo.put("farm", farm);
            dataJo.put("piglet_survival_rate", pigletSurvivalRate);
            resultJa.add(dataJo);
        }
        System.out.println("resultJa>>" + resultJa);
        return resultJa.toJSONString();
    }
}
